@@ -19,15 +19,15 @@ __all__ = [
 ]
 
 
+__author__ = "Isogeo"
+__copyright__ = "2019 - {0}, {1}".format(date.today().year, __author__)
+__email__ = "contact@isogeo.com"
+__license__ = "GNU Lesser General Public License v3.0"
+__summary__ = (
+    "Command-line to read metadata produced by FME scripts of Isogeo Scan, "
+    "convert it into Isogeo model, apply rules and export it to a database or Isogeo."
+)
 __title__ = "Isogeo Scan Metadata Processor"
-__summary__ = "Command-line to read metadata produced by FME scripts of Isogeo Scan, "
-"convert it into Isogeo model, apply rules and export it to a database or Isogeo."
 __uri__ = "https://github.com/isogeo/scan-metadata-processor/"
 
-__version__ = "1.0.2"
-
-__author__ = "Isogeo"
-__email__ = "contact@isogeo.com"
-
-__license__ = "GNU Lesser General Public License v3.0"
-__copyright__ = "2019 - {0}, {1}".format(date.today().year, __author__)
+__version__ = "1.0.4"
