@@ -136,22 +136,41 @@ class LookupToIsogeo:
 
     @property
     def match_format_code(self) -> str:
-        """Guess metadata format."""
+        """Try to match lookup format (FME short and long names) with:
+          1. custom matching table included in submodule
+          2. Isogeo formats registry codes.
+
+        :return: Isogeo format code
+        :rtype: str
+        """
         isogeo_formats_codes = [i.get("code") for i in self.formats]
         # matching format
         md_format = MATCHER_FORMAT.get(self.in_lookup.formatShort)
-
         # first try to refer to Isogeo formats matrix
         if md_format in isogeo_formats_codes:
             logger.debug(
-                "Format '{}' matched Isogeo formats registry: {}".format(
+                "Format '{}' matched custom formats conversion table: {}".format(
                     self.in_lookup.formatShort, md_format
                 )
             )
             out_format_code = md_format
+        elif (
+            isinstance(self.in_lookup.formatShort, str)
+            and self.in_lookup.formatShort.lower() in isogeo_formats_codes
+        ):
+            logger.debug(
+                "Format '{}' found in Isogeo formats registry (codes): {}".format(
+                    self.in_lookup.formatShort.lower(), md_format
+                )
+            )
+            out_format_code = self.in_lookup.formatShort.lower()
         else:
             out_format_code = None
-            logging.warning("Format not recognized: {}".format(self.in_lookup.path))
+            logging.warning(
+                "Format '{}' not recognized for file: {}".format(
+                    self.in_lookup.formatShort, self.in_lookup.path
+                )
+            )
 
         return out_format_code
 
